==> mx-service-manager_25.4.tar.xz: BUILD/translations/mx-service-manager_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>MX Service Manager</source>
        <translation>MX Gestore servizi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="153"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Abilita all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Informazioni...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Help</source>
        <translation>A&amp;iuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Quit application</source>
        <translation> Chiudi applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>&amp;Close</source>
        <translation>C&amp;hiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>All services</source>
        <translation>Tutti i servizi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>Running services</source>
        <translation>Servizi in esecuzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Services enabled at boot</source>
        <translation>Servizi abilitati all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Services disabled at boot</source>
        <translation>Servizi disabilitati all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Questo strumento elenca i servizi e i demoni (processi eseguiti in background) presenti su questo sistema. Fai attenzione a evitare di fermare qualcosa che potrebbe interrompere un componente critico; meglio lasciarlo stare se non sai di cosa si tratti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="388"/>
        <location filename="../mainwindow.cpp" line="395"/>
        <location filename="../mainwindow.cpp" line="416"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Impossibile determinare il sistema di init. Questo programma dovrebbe funzionare sia con systemd che con sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>S&amp;tart</source>
        <translation>A&amp;vvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="146"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Disabilita all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation>%1 servizi totali, %2 attualmente &lt;font color=&apos;%3&apos;&gt;in esecuzione&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation>%1 &lt;font color=&apos;%2&apos;&gt;abilitato&lt;/font&gt; all&apos;avvio, ma non in esecuzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Service and daemon manager</source>
        <translation>Gestore di servizi e demoni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Could not enable %1</source>
        <translation>Impossibile abilitare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="399"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 è stato abilitato all&apos;avvio.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Could not disable %1</source>
        <translation>Impossibile disabilitare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>%1 was disabled.</source>
        <translation>%1 è stato disabilitato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>Could not start %1</source>
        <translation>Impossibile iniziare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>%1 was started.</source>
        <translation>%1 è stato iniziato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Could not stop %1</source>
        <translation>Impossibile fermare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>%1 was stopped.</source>
        <translation>%1 è stato fermato.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembra che tu sia loggato come root, fai il log out e poi il log in come utente normale per usare questo programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Devi eseguire questo programma come amministratore.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="124"/>
        <source>Could not find service description</source>
        <translation>Impossibile trovare la descrizione del servizio</translation>
    </message>
</context>
</TS>

==> mx-service-manager_25.8.tar.xz: BUILD/translations/mx-service-manager_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>MX Service Manager</source>
        <translation>MX Gestore servizi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Abilita all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Informazioni...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Help</source>
        <translation>A&amp;iuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Quit application</source>
        <translation> Chiudi applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>&amp;Close</source>
        <translation>C&amp;hiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>All services</source>
        <translation>Tutti i servizi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Running services</source>
        <translation>Servizi in esecuzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Services enabled at boot</source>
        <translation>Servizi abilitati all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>Services disabled at boot</source>
        <translation>Servizi disabilitati all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="76"/>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Questo strumento elenca i servizi e i demoni (processi eseguiti in background) presenti su questo sistema. Fai attenzione a evitare di fermare qualcosa che potrebbe interrompere un componente critico; meglio lasciarlo stare se non sai di cosa si tratti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="399"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Impossibile determinare il sistema di init. Questo programma dovrebbe funzionare sia con systemd che con sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>S&amp;tart</source>
        <translation>A&amp;vvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Disabilita all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation>%1 servizi totali, %2 attualmente &lt;font color=&apos;%3&apos;&gt;in esecuzione&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation>%1 &lt;font color=&apos;%2&apos;&gt;abilitato&lt;/font&gt; all&apos;avvio, ma non in esecuzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Service and daemon manager</source>
        <translation>Gestore di servizi e demoni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Could not enable %1</source>
        <translation>Impossibile abilitare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 è stato abilitato all&apos;avvio.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Could not disable %1</source>
        <translation>Impossibile disabilitare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>%1 was disabled.</source>
        <translation>%1 è stato disabilitato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Could not start %1</source>
        <translation>Impossibile iniziare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>%1 was started.</source>
        <translation>%1 è stato iniziato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="429"/>
        <source>Could not stop %1</source>
        <translation>Impossibile fermare %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>%1 was stopped.</source>
        <translation>%1 è stato fermato.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembra che tu sia loggato come root, fai il log out e poi il log in come utente normale per usare questo programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Devi eseguire questo programma come amministratore.</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="124"/>
        <source>Could not find service description</source>
        <translation>Impossibile trovare la descrizione del servizio</translation>
    </message>
</context>
</TS>
